@@ -16,9 +16,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id$
  */
 
+#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
+#error "Only <epiphany/epiphany.h> can be included directly."
+#endif
+
 #ifndef EPHY_EMBED_EVENT_H
 #define EPHY_EMBED_EVENT_H
 
@@ -72,8 +75,6 @@ GType			ephy_embed_event_get_type		(void);
 
 GType			ephy_embed_event_context_get_type	(void);
 
-GType			ephy_embed_event_type_get_type 		(void);
-
 EphyEmbedEventContext	ephy_embed_event_get_context	(EphyEmbedEvent *event);
 
 guint			ephy_embed_event_get_button	(EphyEmbedEvent *event);
