@@ -18,7 +18,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id$
  */
 
 #include "config.h"
@@ -35,13 +34,8 @@
 #include <gio/gio.h>
 #include <gio/gdesktopappinfo.h>
 #include <gdk/gdk.h>
-#include <libgnome/gnome-init.h>
 #include <libxml/xmlreader.h>
 
-/* bug http://bugzilla.gnome.org/show_bug.cgi?id=156687 */
-#undef GNOME_DISABLE_DEPRECATED
-#include <libgnome/gnome-desktop-item.h>
-
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
