@@ -15,13 +15,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-search-entry.h 6952 2007-03-11 19:42:02Z chpe $
  */
 
+#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
+#error "Only <epiphany/epiphany.h> can be included directly."
+#endif
+
 #ifndef EPHY_SEARCH_ENTRY_H
 #define EPHY_SEARCH_ENTRY_H
 
-#include <gtk/gtkentry.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -32,9 +35,16 @@ G_BEGIN_DECLS
 #define EPHY_IS_SEARCH_ENTRY_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_SEARCH_ENTRY))
 #define EPHY_SEARCH_ENTRY_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_SEARCH_ENTRY, EphySearchEntryClass))
 
+typedef struct _EphySearchEntryClass	EphySearchEntryClass;
 typedef struct _EphySearchEntry		EphySearchEntry;
 typedef struct _EphySearchEntryPrivate	EphySearchEntryPrivate;
-typedef struct _EphySearchEntryClass	EphySearchEntryClass;
+
+struct _EphySearchEntryClass
+{
+	GtkEntryClass parent;
+
+	void (*search) (EphySearchEntry *view, const char *text);
+};
 
 struct _EphySearchEntry
 {
@@ -44,13 +54,6 @@ struct _EphySearchEntry
 	EphySearchEntryPrivate *priv;
 };
 
-struct _EphySearchEntryClass
-{
-	GtkEntryClass parent;
-
-	void (*search) (EphySearchEntry *view, const char *text);
-};
-
 GType            ephy_search_entry_get_type (void);
 
 GtkWidget       *ephy_search_entry_new      (void);
