@@ -19,7 +19,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-extensions-manager.c 7927 2008-02-10 18:26:22Z xan $
  */
 
 #include "config.h"
@@ -61,6 +60,10 @@
 #include "ephy-python-loader.h"
 #endif
 
+#ifdef ENABLE_SEED
+#include "ephy-seed-loader.h"
+#endif
+
 #define CONF_LOADED_EXTENSIONS	"/apps/epiphany/general/active_extensions"
 #define EE_GROUP		"Epiphany Extension"
 #define DOT_INI			".ephy-extension"
@@ -140,9 +143,9 @@ G_DEFINE_TYPE_WITH_CODE (EphyExtensionsManager, ephy_extensions_manager, G_TYPE_
 /**
  * ephy_extensions_manager_load:
  * @manager: an #EphyExtensionsManager
- * @name: identifier of the extension to load
+ * @identifier: identifier of the extension to load
  *
- * Loads the @name extension.
+ * Loads the extension corresponding to @identifier.
  **/
 void
 ephy_extensions_manager_load (EphyExtensionsManager *manager,
@@ -171,9 +174,9 @@ ephy_extensions_manager_load (EphyExtensionsManager *manager,
 /**
  * ephy_extensions_manager_unload:
  * @manager: an #EphyExtensionsManager
- * @name: filename of extension to unload, minus "lib" and "extension.so"
+ * @identifier: filename of extension to unload, minus "lib" and "extension.so"
  *
- * Unloads the extension specified by @name.
+ * Unloads the extension specified by @identifier.
  *
  * The extension with the same filename can afterwards be reloaded. However,
  * if any GTypes within the extension have changed parent types, Epiphany must
@@ -594,6 +597,20 @@ get_loader_for_type (EphyExtensionsManager *manager,
 #endif
 	}
 
+#ifdef ENABLE_SEED
+	if (strcmp (type, "seed") == 0)
+	{
+		info = g_new (LoaderInfo, 1);
+		info->type = g_strdup (type);
+		info->loader = g_object_new (EPHY_TYPE_SEED_LOADER, NULL);
+
+		manager->priv->factories =
+				g_list_append (manager->priv->factories, info);
+
+		return g_object_ref (info->loader);
+		return NULL;
+	}
+#endif
 	shlib_loader = get_loader_for_type (manager, "shlib");
 	g_return_val_if_fail (shlib_loader != NULL, NULL);
 
