@@ -16,7 +16,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: popup-commands.c 7981 2008-02-25 19:37:26Z chpe $
  */
 
 #include "config.h"
@@ -33,8 +32,7 @@
 
 #include <string.h>
 #include <glib/gi18n.h>
-#include <gtk/gtkclipboard.h>
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 
 void
 popup_cmd_link_in_new_window (GtkAction *action,
